BaseDataModel<R> class abstract

An abstract interface class for network data.

Constructors

BaseDataModel()
Creates a new instance of BaseDataModel.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

fromJson(String json) → R
Converts the object from a JSON string representation.
fromMap(Map<String, dynamic> map) → R
Converts the object from a Map representation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts the object to a JSON string representation.
toMap() Map<String, dynamic>
Converts the BaseDataModel object to a Map representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited