ListParserExtensions extension

Extension methods for the List class.

on

Properties

serializeListItems List<Object?>

Available on List<Object?>, provided by the ListParserExtensions extension

Serializes the list items to a list of serializable objects.
no setter

Methods

castListToTypes(String itemType) List<Object?>?

Available on List<Object?>, provided by the ListParserExtensions extension

Casts a list of items to the specified type.
deserializeListByType<T>() List<T>?

Available on List<Object?>, provided by the ListParserExtensions extension

Safely deserializes a list of items to the specified type T.
deserializeListItems<T>() → T?

Available on List<Object?>, provided by the ListParserExtensions extension

Safely deserializes a list of items to the specified type T.