MapParserExtensions extension

Extension methods for safely parsing values from maps.

on

Methods

parse<T>(String keyName) → T?

Available on Map, provided by the MapParserExtensions extension

Safely parses a value from the map with the specified key name.
parseDefault<T>(String keyName, T defaultValue) → T

Available on Map, provided by the MapParserExtensions extension

Safely parses a value from the map with the specified key name.