SerializationExtensions extension

Extension methods for serializing and deserializing objects

on

Properties

toSerializable Object?

Available on Object?, provided by the SerializationExtensions extension

Converts an object to a serializable format
no setter

Methods

fromSerializable<T>() → T?

Available on Object?, provided by the SerializationExtensions extension

Attempts to convert a serialized value to type T
fromSerializableDefault<T>(T defaultValue) → T

Available on Object?, provided by the SerializationExtensions extension

Attempts to convert a serialized value to type T, returning default if conversion fails
toList() List<Object?>?

Available on Object?, provided by the SerializationExtensions extension

Safe conversion to List<Object?>
toMap() Map<String, Object?>?

Available on Object?, provided by the SerializationExtensions extension

Safe conversion to Map<String, Object?>