ListParserExtensions extension
Extension methods for the List class.
Properties
-
serializeListItems
→ List<
Object?> -
Available on List<
Serializes the list items to a list of serializable objects.Object?> , provided by the ListParserExtensions extensionno setter
Methods
-
castListToTypes(
String itemType) → List< Object?> ? -
Available on List<
Casts a list of items to the specified type.Object?> , provided by the ListParserExtensions extension -
deserializeListByType<
T> () → List< T> ? -
Available on List<
Safely deserializes a list of items to the specified typeObject?> , provided by the ListParserExtensions extensionT. -
deserializeListItems<
T> () → T? -
Available on List<
Safely deserializes a list of items to the specified typeObject?> , provided by the ListParserExtensions extensionT.