A class that provides safe JSON encoding and decoding methods.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
safeDecodeJson(
String json) → Object? - Safely decodes a JSON string to an object with error handling Intelligently handles cases where input might not be valid JSON
-
safeEncodeJson(
Object? object) → String - Safely encodes an object to JSON string with error handling.