StringTypeConversionExtensions extension
Extension methods for the String class.
- on
Properties
- isComplexType → bool
-
Available on String, provided by the StringTypeConversionExtensions extension
Returns true if the string is a complex type, otherwise returns false.no setter
Methods
-
toColor(
) → Color? -
Available on String, provided by the StringTypeConversionExtensions extension
Converts the string to a color. NOTE: Normally color format is ARGB in Flutter, but this method accepts RGB and RGBA formats as well. -
toEnum<
T extends Enum> (List< T> values) → T? -
Available on String, provided by the StringTypeConversionExtensions extension
Converts the string to an enum according to the given list of values.