StringUtilExtensions extension
Utility functions on nullable strings.
- on
Properties
- isJsonArray → bool
-
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string is a JSON array, otherwise returns false.no setter - isJsonObject → bool
-
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string is a JSON object, otherwise returns false.no setter - isJsonPrimitive → bool
-
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string is a JSON primitive, otherwise returns false.no setter - isNullEmpty → bool
-
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string is null or empty, otherwise returns false.no setter - isNullString → bool
-
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string is null or "null", otherwise returns false.no setter
Methods
-
compareWithoutCase(
String? otherString) → bool -
Available on String?, provided by the StringUtilExtensions extension
Compares two strings by ignoring case differences. -
compareWithoutCaseAny(
List< String> otherStrings) → bool -
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string matches any of the other strings by ignoring case, otherwise returns false. -
containsWithoutCase(
String? otherString) → bool -
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string contains the other string by ignoring case, otherwise returns false. -
startsWithIgnoreCase(
String? otherString) → bool -
Available on String?, provided by the StringUtilExtensions extension
Returns true if the string starts with the other string by ignoring case, otherwise returns false.